// IBM Confidential OCO Source Material
// 5724-J34 (C) COPYRIGHT International Business Machines Corp. 2005
// The source code for this program is not published or otherwise divested
// of its trade secrets, irrespective of what has been deposited with the
// U.S. Copyright Office.


package com.ibm.websphere.longrun;


/**
 *
 * Represents the job status codes stored in the job scheduler database.
 * These are the status codes returned by the job scheduler EJB and the 
 * lrcmd client.
 * 
 * @ibm-api
 */
public class JobStatusConstants  {

    
    /**
     * Job has been submitted to the job scheduler but has not yet been started on a grid endpoint
     */
    public static final int SUBMITTED = 0;
    
    /**
     * A cancel request was received by the job scheduler and the grid endpoint is in the process of 
     * canceling the job.
     */
    public static final int CANCEL_PENDING = 1;
    
    /**
     * A suspend request was received by the job scheduler and the
     * grid endpoint is in the process of suspending the job.  Applies to batch jobs only. 
     */
    public static final int SUSPEND_PENDING = 2;

    /**
     * A resume request was received by the job scheduler and the
     * grid endpoint is in the process of resuming the job.  Applies to batch jobs only.
     */
    public static final int RESUME_PENDING = 3;

    /**
     * Job is currently executing on a grid endpoint.
     */
    public static final int EXECUTING = 4;

    /**
     * Job is currently suspended on the grid endpoint
     */
    public static final int SUSPENDED = 5;

    /**
     * The job has been canceled successfully.  Applies to compute-intensive jobs only.
     */
    public static final int CANCELLED = 6;

    /**
     * Job has ended successfully.
     */
    public static final int ENDED = 7;

    /**
     * The job is restartable.  Batch jobs that fail or are canceled, go into the 
     * RESTARTABLE state.  Applies to batch jobs only.
     */
    public static final int RESTARTABLE = 8;

    /**
     * Error occurred while running a compute-intensive job or setting up a j2ee job.
     */
    public static final int EXECUTION_FAILED = 9;

    /**
     * A delayed job is waiting to be submitted based on the start time for the job
     */
    public static final int PENDING_SUBMIT = 10;

    /**
     * A stop request was received by the job scheduler and the grid endpoint is in 
     * the process of stopping the job.
     */
    public static final int STOP_PENDING = 11;

    /**
     * Job is stopped.  Applies to batch jobs only. 
     */
    public static final int STOPPED = 12;
    
    /**
     * A worker thread has been dispatched to execute the job
     */
    
    public static final int DISPATCHED = 13;
    
    
    /**
     * Job is in the process of being setup
     */
    public static final int IN_SETUP = 14;
    
    
    /**
     * NO step status
     */
    public static final int NOT_STARTED = 15;

    /**
     * UNKNOWN status
     */
    public static final int UNKNOWN = 16;

    /**
     * Descriptive text for the job status codes.
     */
    public static final String[] statusText = {
        "submitted",
        "cancel pending",
        "suspend pending",
        "resume pending",
        "executing",
        "suspended",
        "cancelled",
        "ended",
        "restartable",
        "execution failed",
        "pending submit", 
        "stop pending",
        "stopped",
        "dispatched",
        "insetup",
        "not started",
        "unknown"
    };

    /**
     * JMX notification constants
     */

    /*public static final String[] jmxNotificationConstants = {

        JobStatusJMXNotificationData.JOB_STATE_SUBMITTED,
        JobStatusJMXNotificationData.JOB_STATE_CANCEL_PENDING,
        JobStatusJMXNotificationData.JOB_STATE_SUSPEND_PENDING,
        JobStatusJMXNotificationData.JOB_STATE_RESUME_PENDING,
        JobStatusJMXNotificationData.JOB_STATE_STARTED,
        JobStatusJMXNotificationData.JOB_STATE_SUSPENDED,
        JobStatusJMXNotificationData.JOB_STATE_ENDED,
        JobStatusJMXNotificationData.JOB_STATE_ENDED,
        JobStatusJMXNotificationData.JOB_STATE_ENDED,
        JobStatusJMXNotificationData.JOB_STATE_ENDED,
        JobStatusJMXNotificationData.JOB_STATE_SUBMIT_PENDING,
        JobStatusJMXNotificationData.JOB_STATE_STOP_PENDING,
        JobStatusJMXNotificationData.JOB_STATE_STOPPED
    };
*/
}
