package com.ibm.wsspi.batch;

import com.ibm.websphere.grid.spi.SPI;

/**
 * LifeCycle is the abstract base class for the LifeCycle System Programming Interface (SPI).
 * Use the LifeCycle SPI to receive job state change notifications.  Each time a job transitions 
 * from one state to another, this SPI is invoked, indicating the new state for the affected 
 * job.  
 * <p>
 * Implement the LifeCycle SPI, by extending this class and implementing the stateChanged
 * method.  
 * <p>
 * Configure this SPI with the following declaration in the xd.spi.properties file:
 * <p>
 * <pre>
 * spi.LifeCycle=&lt;fully-qualified implementation class name&gt;
 * </pre>
 * <p>
 * <b>Notes:</b> 
 * <ol>
 * <li>The xd.spi.properties file is located in:</li>
 * <p>
 * <pre>
 * &lt;WAS install root&gt;/properties.  E.g.
 * 
 *       /WebSphere/AppServer/properties
 * </pre>
 * <li>The jar file containing the implementation of this SPI should be stored in:</li>
 * <p>
 * <pre>
 * &lt;WAS install root&gt;/lib/classes.  E.g.
 * 
 *       /WebSphere/AppServer/lib/classes
 * </pre> 
 * You are responsible for creating the classes directory if it does not already exist. 
 * @ibm-spi
 */

public abstract class LifeCycle extends SPI {
	
	/**
	 * Callback invoked by job scheduler when a job changes state.
	 * @param jobID specifies the job ID of the job that has changed state.
	 * @param newState specifies the new state of the job.
	 * @see com.ibm.websphere.longrun.JobStatusConstants Job State Constants 
	 */
	
	public abstract void stateChanged(	String jobID,
										int newState); 
	
	
	public String getName() {
		return "LifeCycle";
	}

}
